# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Union, Optional
from typing_extensions import Literal, Required, TypedDict

from .._types import SequenceNotStr

__all__ = ["EmbeddingCreateParams"]


class EmbeddingCreateParams(TypedDict, total=False):
    model: Required[Literal["kanon-2-embedder"]]
    """
    The ID of the [model](https://docs.isaacus.com/models#embedding) to use for
    embedding.
    """

    texts: Required[Union[SequenceNotStr[str], str]]
    """The text or array of texts to embed.

    Each text must contain at least one non-whitespace character.

    No more than 128 texts can be embedded in a single request.
    """

    dimensions: Optional[int]
    """A whole number greater than or equal to 1."""

    overflow_strategy: Optional[Literal["drop_end"]]
    """The strategy to employ when content exceeds the model's maximum input length.

    `drop_end`, which is the default setting, drops tokens from the end of the
    content exceeding the limit.

    If `null`, an error will be raised if any content exceeds the model's maximum
    input length.
    """

    task: Optional[Literal["retrieval/query", "retrieval/document"]]
    """The task the embeddings will be used for.

    `retrieval/query` is meant for queries and statements, and `retrieval/document`
    is meant for anything to be retrieved using query embeddings.

    If `null`, which is the default setting, embeddings will not be optimized for
    any particular task.
    """



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .embedding_response import EmbeddingResponse as EmbeddingResponse
from .reranking_response import RerankingResponse as RerankingResponse
from .embedding_create_params import EmbeddingCreateParams as EmbeddingCreateParams
from .reranking_create_params import RerankingCreateParams as RerankingCreateParams



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Literal

import httpx

from ..types import reranking_create_params
from .._types import Body, Omit, Query, Headers, NotGiven, SequenceNotStr, omit, not_given
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.reranking_response import RerankingResponse

__all__ = ["RerankingsResource", "AsyncRerankingsResource"]


class RerankingsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> RerankingsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/isaacus-dev/isaacus-python#accessing-raw-response-data-eg-headers
        """
        return RerankingsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> RerankingsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/isaacus-dev/isaacus-python#with_streaming_response
        """
        return RerankingsResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        model: Literal["kanon-universal-classifier", "kanon-universal-classifier-mini"],
        query: str,
        texts: SequenceNotStr[str],
        chunking_options: Optional[reranking_create_params.ChunkingOptions] | Omit = omit,
        is_iql: bool | Omit = omit,
        scoring_method: Literal["auto", "chunk_max", "chunk_avg", "chunk_min"] | Omit = omit,
        top_n: Optional[int] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> RerankingResponse:
        """
        Rerank legal documents by their relevance to a query with an Isaacus legal AI
        reranker.

        Args:
          model: The ID of the [model](https://docs.isaacus.com/models#reranking) to use for
              reranking.

          query: The query to evaluate the relevance of the texts to.

              The query must contain at least one non-whitespace character.

              Unlike the texts being reranked, the query cannot be so long that it exceeds the
              maximum input length of the reranker.

          texts: The texts to rerank.

              There must be at least one text.

              Each text must contain at least one non-whitespace character.

          chunking_options: Options for how to split text into smaller chunks.

          is_iql: Whether the query should be interpreted as an
              [Isaacus Query Language (IQL)](https://docs.isaacus.com/iql) query, which is not
              the case by default.

              If you allow untrusted users to construct their own queries, think carefully
              before enabling IQL since queries can be crafted to consume an excessively large
              amount of tokens.

          scoring_method: The method to use for producing an overall relevance score for a text.

              `auto` is the default scoring method and is recommended for most use cases.
              Currently, it is equivalent to `chunk_max`. In the future, it will automatically
              select the best method based on the model and inputs.

              `chunk_max` uses the highest relevance score of all of a text's chunks.

              `chunk_avg` averages the relevance scores of all of a text's chunks.

              `chunk_min` uses the lowest relevance score of all of a text's chunks.

          top_n: A whole number greater than or equal to 1.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/rerankings",
            body=maybe_transform(
                {
                    "model": model,
                    "query": query,
                    "texts": texts,
                    "chunking_options": chunking_options,
                    "is_iql": is_iql,
                    "scoring_method": scoring_method,
                    "top_n": top_n,
                },
                reranking_create_params.RerankingCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=RerankingResponse,
        )


class AsyncRerankingsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncRerankingsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/isaacus-dev/isaacus-python#accessing-raw-response-data-eg-headers
        """
        return AsyncRerankingsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncRerankingsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/isaacus-dev/isaacus-python#with_streaming_response
        """
        return AsyncRerankingsResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        model: Literal["kanon-universal-classifier", "kanon-universal-classifier-mini"],
        query: str,
        texts: SequenceNotStr[str],
        chunking_options: Optional[reranking_create_params.ChunkingOptions] | Omit = omit,
        is_iql: bool | Omit = omit,
        scoring_method: Literal["auto", "chunk_max", "chunk_avg", "chunk_min"] | Omit = omit,
        top_n: Optional[int] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> RerankingResponse:
        """
        Rerank legal documents by their relevance to a query with an Isaacus legal AI
        reranker.

        Args:
          model: The ID of the [model](https://docs.isaacus.com/models#reranking) to use for
              reranking.

          query: The query to evaluate the relevance of the texts to.

              The query must contain at least one non-whitespace character.

              Unlike the texts being reranked, the query cannot be so long that it exceeds the
              maximum input length of the reranker.

          texts: The texts to rerank.

              There must be at least one text.

              Each text must contain at least one non-whitespace character.

          chunking_options: Options for how to split text into smaller chunks.

          is_iql: Whether the query should be interpreted as an
              [Isaacus Query Language (IQL)](https://docs.isaacus.com/iql) query, which is not
              the case by default.

              If you allow untrusted users to construct their own queries, think carefully
              before enabling IQL since queries can be crafted to consume an excessively large
              amount of tokens.

          scoring_method: The method to use for producing an overall relevance score for a text.

              `auto` is the default scoring method and is recommended for most use cases.
              Currently, it is equivalent to `chunk_max`. In the future, it will automatically
              select the best method based on the model and inputs.

              `chunk_max` uses the highest relevance score of all of a text's chunks.

              `chunk_avg` averages the relevance scores of all of a text's chunks.

              `chunk_min` uses the lowest relevance score of all of a text's chunks.

          top_n: A whole number greater than or equal to 1.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/rerankings",
            body=await async_maybe_transform(
                {
                    "model": model,
                    "query": query,
                    "texts": texts,
                    "chunking_options": chunking_options,
                    "is_iql": is_iql,
                    "scoring_method": scoring_method,
                    "top_n": top_n,
                },
                reranking_create_params.RerankingCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=RerankingResponse,
        )


class RerankingsResourceWithRawResponse:
    def __init__(self, rerankings: RerankingsResource) -> None:
        self._rerankings = rerankings

        self.create = to_raw_response_wrapper(
            rerankings.create,
        )


class AsyncRerankingsResourceWithRawResponse:
    def __init__(self, rerankings: AsyncRerankingsResource) -> None:
        self._rerankings = rerankings

        self.create = async_to_raw_response_wrapper(
            rerankings.create,
        )


class RerankingsResourceWithStreamingResponse:
    def __init__(self, rerankings: RerankingsResource) -> None:
        self._rerankings = rerankings

        self.create = to_streamed_response_wrapper(
            rerankings.create,
        )


class AsyncRerankingsResourceWithStreamingResponse:
    def __init__(self, rerankings: AsyncRerankingsResource) -> None:
        self._rerankings = rerankings

        self.create = async_to_streamed_response_wrapper(
            rerankings.create,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .qa import (
    QaResource,
    AsyncQaResource,
    QaResourceWithRawResponse,
    AsyncQaResourceWithRawResponse,
    QaResourceWithStreamingResponse,
    AsyncQaResourceWithStreamingResponse,
)
from .extractions import (
    ExtractionsResource,
    AsyncExtractionsResource,
    ExtractionsResourceWithRawResponse,
    AsyncExtractionsResourceWithRawResponse,
    ExtractionsResourceWithStreamingResponse,
    AsyncExtractionsResourceWithStreamingResponse,
)

__all__ = [
    "QaResource",
    "AsyncQaResource",
    "QaResourceWithRawResponse",
    "AsyncQaResourceWithRawResponse",
    "QaResourceWithStreamingResponse",
    "AsyncQaResourceWithStreamingResponse",
    "ExtractionsResource",
    "AsyncExtractionsResource",
    "ExtractionsResourceWithRawResponse",
    "AsyncExtractionsResourceWithRawResponse",
    "ExtractionsResourceWithStreamingResponse",
    "AsyncExtractionsResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Literal, Required, TypedDict

from ..._types import SequenceNotStr

__all__ = ["UniversalCreateParams", "ChunkingOptions"]


class UniversalCreateParams(TypedDict, total=False):
    model: Required[Literal["kanon-universal-classifier", "kanon-universal-classifier-mini"]]
    """
    The ID of the [model](https://docs.isaacus.com/models#universal-classification)
    to use for universal classification.
    """

    query: Required[str]
    """
    The [Isaacus Query Language (IQL)](https://docs.isaacus.com/iql) query or, if
    IQL is disabled, the statement, to evaluate the texts against.

    The query must contain at least one non-whitespace character.

    Unlike the texts being classified, the query cannot be so long that it exceeds
    the maximum input length of the universal classifier.
    """

    texts: Required[SequenceNotStr[str]]
    """The texts to classify.

    Each text must contain at least one non-whitespace character.
    """

    chunking_options: Optional[ChunkingOptions]
    """Options for how to split text into smaller chunks."""

    is_iql: bool
    """
    Whether the query should be interpreted as an
    [IQL](https://docs.isaacus.com/iql) query or else as a statement.
    """

    scoring_method: Literal["auto", "chunk_max", "chunk_avg", "chunk_min"]
    """The method to use for producing an overall confidence score.

    `auto` is the default scoring method and is recommended for most use cases.
    Currently, it is equivalent to `chunk_max`. In the future, it will automatically
    select the best method based on the model and inputs.

    `chunk_max` uses the highest confidence score of all of the texts' chunks.

    `chunk_avg` averages the confidence scores of all of the texts' chunks.

    `chunk_min` uses the lowest confidence score of all of the texts' chunks.
    """


class ChunkingOptions(TypedDict, total=False):
    overlap_ratio: Optional[float]
    """A number greater than or equal to 0 and less than 1."""

    overlap_tokens: Optional[int]
    """A whole number greater than -1."""

    size: Optional[int]
    """A whole number greater than or equal to 1."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from ..._compat import cached_property
from .universal import (
    UniversalResource,
    AsyncUniversalResource,
    UniversalResourceWithRawResponse,
    AsyncUniversalResourceWithRawResponse,
    UniversalResourceWithStreamingResponse,
    AsyncUniversalResourceWithStreamingResponse,
)
from ..._resource import SyncAPIResource, AsyncAPIResource

__all__ = ["ClassificationsResource", "AsyncClassificationsResource"]


class ClassificationsResource(SyncAPIResource):
    @cached_property
    def universal(self) -> UniversalResource:
        return UniversalResource(self._client)

    @cached_property
    def with_raw_response(self) -> ClassificationsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/isaacus-dev/isaacus-python#accessing-raw-response-data-eg-headers
        """
        return ClassificationsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> ClassificationsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/isaacus-dev/isaacus-python#with_streaming_response
        """
        return ClassificationsResourceWithStreamingResponse(self)


class AsyncClassificationsResource(AsyncAPIResource):
    @cached_property
    def universal(self) -> AsyncUniversalResource:
        return AsyncUniversalResource(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncClassificationsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/isaacus-dev/isaacus-python#accessing-raw-response-data-eg-headers
        """
        return AsyncClassificationsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncClassificationsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/isaacus-dev/isaacus-python#with_streaming_response
        """
        return AsyncClassificationsResourceWithStreamingResponse(self)


class ClassificationsResourceWithRawResponse:
    def __init__(self, classifications: ClassificationsResource) -> None:
        self._classifications = classifications

    @cached_property
    def universal(self) -> UniversalResourceWithRawResponse:
        return UniversalResourceWithRawResponse(self._classifications.universal)


class AsyncClassificationsResourceWithRawResponse:
    def __init__(self, classifications: AsyncClassificationsResource) -> None:
        self._classifications = classifications

    @cached_property
    def universal(self) -> AsyncUniversalResourceWithRawResponse:
        return AsyncUniversalResourceWithRawResponse(self._classifications.universal)


class ClassificationsResourceWithStreamingResponse:
    def __init__(self, classifications: ClassificationsResource) -> None:
        self._classifications = classifications

    @cached_property
    def universal(self) -> UniversalResourceWithStreamingResponse:
        return UniversalResourceWithStreamingResponse(self._classifications.universal)


class AsyncClassificationsResourceWithStreamingResponse:
    def __init__(self, classifications: AsyncClassificationsResource) -> None:
        self._classifications = classifications

    @cached_property
    def universal(self) -> AsyncUniversalResourceWithStreamingResponse:
        return AsyncUniversalResourceWithStreamingResponse(self._classifications.universal)
